package org.apache.xindice.client.xmldb.services;

/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 1999 The Apache Software Foundation.  All rights
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "Xindice" and "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation and was
 * originally based on software copyright (c) 1999-2001, The dbXML
 * Group, L.L.C., http://www.dbxmlgroup.com.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 *
 * $Id: CollectionManager.java,v 1.7 2002/11/22 10:15:34 vladimir Exp $
 */

import org.w3c.dom.*;
import org.xmldb.api.base.Collection;
import org.xmldb.api.base.XMLDBException;

/**
 * CollectionManager provides management facilities for a Collection instance.
 * Administrative access is required for retrieval of the CollectionManager
 * interface. User level access is provided through the underlying Collection
 * itself.
 */
public interface CollectionManager {   
   /**
    * Returns the name of the collection that this manager is associated with.
    *
    * @return the name of the collection
    * @exception XMLDBException
    */
   public String getCollectionName() throws XMLDBException;

   /**
    * Returns the fully qualified name of the collection that this manager is
    * associated with. This name includes all parent collections.
    *
    * @return the fully qualified name for this collection.
    * @exception XMLDBException
    */
   public String getCanonicalName() throws XMLDBException;

   /**
    * Creates a new collection in the database identified by name and using
    * the provided configuration.
    *
    * @param path the path of the new collection
    * @param configuration the XML collection configuration to use for
    *        creating this collection.
    * @return The newly created collection
    * @exception XMLDBException
    */
   public Collection createCollection(String path, Document configuration)
         throws XMLDBException;
   
   /**
    * Drops a child collection from this collection.
    *
    * @param name The name of the child collection to drop.
    * @exception XMLDBException
    */
   public void dropCollection(String name) throws XMLDBException;

   /**
    * Returns a list of all indexers for this collection.
    *
    * @return the list of indexers
    * @exception XMLDBException
    */
   public String[] listIndexers() throws XMLDBException;

   /**
    * Creates a new Indexer for this collection.
    *
    * @param configuration The configuration to use for this indexer.
    * @exception XMLDBException
    */
   public void createIndexer(Document configuration)
         throws XMLDBException;

   /**
    * Drops the indexer from the collection
    *
    * @param name The name of the indexer to drop.
    * @exception XMLDBException
    */
   public void dropIndexer(String name)
         throws XMLDBException;

   /**
    * Returns a list of all collection level XMLObjects for this collection.
    *
    * @return the list of XMLObjects.
    * @exception XMLDBException
    */
  public String[] listXMLObjects() throws XMLDBException;
   
   /**
    * Creates a new collection level XMLObject using the provided configuration.
    * The XMLObject will be added to the collection using the provided name as
    * a key.
    *
    * @param configuration The XML configuration to use
    * @exception XMLDBException
    */
   public void createXMLObject(Document configuration) throws XMLDBException;

   /**
    * Drops a collection level XMLObject from the collection.
    *
    * @param name The name of the XMLObject to drop.
    * @exception XMLDBException
    */
   public void dropXMLObject(String name)
         throws XMLDBException;
}

