/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 1999 The Apache Software Foundation.  All rights
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "Xindice" and "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation and was
 * originally based on software copyright (c) 1999-2001, The dbXML
 * Group, L.L.C., http://www.dbxmlgroup.com.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 *
 * $Id: IndexTest.java,v 1.3 2002/10/28 08:39:20 vladimir Exp $
 */

package org.apache.xindice.integration.client.basic;

import org.apache.xindice.integration.client.AbstractXmlDbClientTest;
import org.apache.xindice.util.XindiceException;

import org.xmldb.api.base.XMLDBException;

import java.util.Arrays;
import java.util.Vector;

/**
 * @version $Revision: 1.3 $, $Date: 2002/10/28 08:39:20 $
 * @author Vladimir R. Bossicard <vladimir@apache.org>
 */
public class IndexTest
      extends AbstractXmlDbClientTest {


   public void testCreateIndexer()
         throws Exception {
      this.client.createIndexer(TEST_COLLECTION_PATH, "goodindexer", getIndexDef("goodindexer"));
      this.client.dropIndexer(TEST_COLLECTION_PATH, "goodindexer");
   }

   private String getIndexDef(String name) {
      return "<?xml version=\"1.0\"?><index class=\"org.apache.xindice.core.indexer.ValueIndexer\" name=\"" + name + "\" pattern=\"pattern\" />";
   }

   public void testCreateDuplicateIndexer()
         throws Exception {
      this.client.createIndexer(TEST_COLLECTION_PATH, "duplicate", getIndexDef("duplicate"));
      try {
         this.client.createIndexer(TEST_COLLECTION_PATH, "duplicate", getIndexDef("duplicate"));
         fail();
      } catch (XMLDBException e) {
         //assertTrue( e.getMessage().lastIndexOf( "No name specified" ) > 0 );
      } finally {
         this.client.dropIndexer(TEST_COLLECTION_PATH, "duplicate");
      }
   }

   public void testCreateIndexerEmptyName()
         throws Exception {
      try {
         this.client.createIndexer(TEST_COLLECTION_PATH, "", getIndexDef(""));
      } catch (XMLDBException e) {
         //assertTrue( e.getMessage().lastIndexOf( "No name specified" ) > 0 );
         return;
      }
      fail();
   }

   public void testCreateIndexerNullName()
         throws Exception {
      try {
         this.client.createIndexer(TEST_COLLECTION_PATH, null, getIndexDef(""));
      } catch (XMLDBException e) {
         //assertTrue( e.getMessage().lastIndexOf( "No name specified" ) > 0 );
         return;
      }
      fail();
   }

   public void testCreateIndexerNullDefinition()
         throws Exception {
      try {
         this.client.createIndexer(TEST_COLLECTION_PATH, "index", null);
      } catch (XindiceException e) {
         //assertTrue( e.getMessage().lastIndexOf( "No name specified" ) > 0 );
         return;
      }
      fail();
   }

   public void testCreateIndexerInvalidDefinition()
         throws Exception {
      try {
         this.client.createIndexer(TEST_COLLECTION_PATH, "index", "blah");
      } catch (XindiceException e) {
         //assertTrue( e.getMessage().lastIndexOf( "No name specified" ) > 0 );
         return;
      }
      fail();
   }

   public void testDropIndexerTwice()
         throws Exception {
      this.client.createIndexer(TEST_COLLECTION_PATH, "droptwice", getIndexDef("droptwice"));
      this.client.dropIndexer(TEST_COLLECTION_PATH, "droptwice");

      // drop the newly created index
      try {
         this.client.dropIndexer(TEST_COLLECTION_PATH, "droptwice");
      } catch (XMLDBException e) {
         //assertTrue( e.getMessage().lastIndexOf( "Index Value Null" ) > 0 );
         return;
      }
      fail();
   }

   public void testDropIndexerInvalidName()
         throws Exception {
      try {
         this.client.dropIndexer(TEST_COLLECTION_PATH, "");
      } catch (XMLDBException e) {
         //assertTrue( e.getMessage().lastIndexOf( "Index Value Null" ) > 0 );
         return;
      }
      fail();
   }

   public void testDropIndexerNullName()
         throws Exception {
      try {
         this.client.dropIndexer(TEST_COLLECTION_PATH, null);
      } catch (XMLDBException e) {
         //assertTrue( e.getMessage().lastIndexOf( "Index Value Null" ) > 0 );
         return;
      }
      fail();
   }

   public void testListIndexers()
         throws Exception {
      String[] indexes = this.client.listIndexes(TEST_COLLECTION_PATH);
      assertEquals(0, indexes.length);

      this.client.createIndexer(TEST_COLLECTION_PATH, "index1", getIndexDef("index1"));
      indexes = this.client.listIndexes(TEST_COLLECTION_PATH);
      assertEquals(1, indexes.length);
      assertEquals("index1", indexes[0]);

      this.client.createIndexer(TEST_COLLECTION_PATH, "index2", getIndexDef("index2"));
      indexes = this.client.listIndexes(TEST_COLLECTION_PATH);
      assertEquals(2, indexes.length);
      Vector lst = new Vector(Arrays.asList(indexes));
      assertTrue(lst.contains("index1"));
      assertTrue(lst.contains("index2"));

      this.client.dropIndexer(TEST_COLLECTION_PATH, "index1");
      indexes = this.client.listIndexes(TEST_COLLECTION_PATH);
      assertEquals(1, indexes.length);
      assertEquals("index2", indexes[0]);

      this.client.dropIndexer(TEST_COLLECTION_PATH, "index2");
      indexes = this.client.listIndexes(TEST_COLLECTION_PATH);
      assertEquals(0, indexes.length);
   }

}
